import React, { useState, useEffect } from 'react'
import { Modal, Row, Col, Space, Form, Input, Select, message} from 'antd'

import { getAgent } from '@/services/agent'

import { postOrPutNotice } from '@/services/notice'

import type { noticeModalProps } from './data'

const layout = {
    labelCol: { span: 5 },
    wrapperCol: { span: 16 },
};

const NoticeModal: React.FC<noticeModalProps> = ({GetNotice, type, closeModal, visible, curNoticeData}) => {
    
    const [form] = Form.useForm();

    const [agentList, setAgentList ] = useState([])

    const [label, setLabel ] = useState('')

    const [ content, setContent ] = useState('')


    // 获取所有的代理商
    const GetAgent = async (): Promise<void> => {
        const $par = {
            curPage: 1,
            pageSize: 10000
        }
      const { code, data } = await getAgent($par)
      if (code === 0) {
          console.log(data);
          const { records } = data
          setAgentList(records)
      }
    }
    
    // 新增或者编辑公告
    const PostOrPutNotice = async (record: any): Promise<void> => {

       const { code, data } =  await postOrPutNotice(record)
       if (code === 0) {
           console.log(data);
            message.success('新增成功')
       }
       closeModal()
       GetNotice()
    }  
    
    
    // 反填表单
    const onFill = (): void => {
        console.log(curNoticeData);
        const $par = {...curNoticeData, userIds: curNoticeData.userIds.join('')}
        form.setFieldsValue($par)
    }

    const onFinish = (values: any) => {
        const $par = {
            ...values,
            userIds: values.userIds.split(''),
            type
          }
          PostOrPutNotice($par)
      };
    
    // 提交表单
    const onsubmit = (): void => form.submit()

    // 设置标题
    const changeLabel = (e: React.ChangeEvent<HTMLInputElement>): void => setLabel(e.target.value)

    // 内容
    const changeContent = (e: React.ChangeEvent<HTMLInputElement>): void => setContent(e.target.value)

    useEffect (() => {
        GetAgent()
        // onFill()
    }, []) 
    return (
        <Modal visible={visible} title="发布公告" onOk={() => onsubmit()} onCancel={closeModal}>
            <Form  {...layout} form={form} onFinish={onFinish}>
                <Form.Item name="label" label="公告标题:"><Input onChange={changeLabel} maxLength={80}></Input></Form.Item>
                <Form.Item name="content" label="公告内容:"><Input.TextArea rows={4} onChange={changeContent} ></Input.TextArea></Form.Item>
                <Form.Item name="userIds" label="可看人员:">
                    <Select>
                        {
                            agentList.length && agentList.map( (item: Record<string, any>) => (
                                <Select.Option key={item.id} value={item.id}>
                                    {item.nickName}
                                </Select.Option>
                            ))
                        }
                        
                    </Select>
                </Form.Item>
            </Form>
        </Modal>
    )
}

export default NoticeModal